Changelog
=========

1.3.3 (03/21/21)
----------------
*   colab badge and link
*   change theme for sphinx documentation
*   add requirements.txt to avoid installing sphinx
*   fix restructured text errors
*   advise everywhere to `pip install --user miepython` to avoid permission problems

1.3.2 (01/13/21)
----------------
*   add ez_mie(m, d, lambda0)
*   add ez_intensities(m, d, lambda0, mu)
*   fix formatting
*   fix api autodoc
*   specify newer pythons
*   better install instructions

1.3.1 (03/30/20)
----------------
*   improve docstrings
*   use Sphinx documentation
*   host docs on readthedocs.io
*   use tox

1.3.0 (02/19/19)
----------------
*   fix calculations for small spheres (x<0.05)
*   added notebook doc/09_backscattering.ipynb
*   general tweaks to documentation throughout
*   improved README.md

1.2.0. (02/08/19)
-----------------
*   fix bug so that large sphere calculations work correctly
*   add tests for large spheres
*   add tests for backscattering efficiency
*   add documentation notebook for large spheres
*   add direct links to documentation
*   finish fixing fractions in notebooks
*   improve README.md

1.1.1. (06/25/18)
------------------
*   fix github rendering of fractions in equations
*   add developer instructions
*   fix fractions for github
*   add missing doc files found my check-manifest
*   setup.py fixes suggested by pyroma
*   pep8 compliance and delinting using pylint
*   add missing doc files found my check-manifest
*   setup.py fixes suggested by pyroma
*   pep8 compliance and delinting using pylint
*   update version
*   add notebook doc/08_large_spheres.ipynb

1.1.0 (03/02/2018)
------------------
*   update version
*   initial commit of 04_rayleigh.ipynb
*   renamed doc files
*   use new functions from miepython
*   omit low level tests
*   add __author__ and __version__
*   add i_par, i_per, i_unpolarized, and hide private functions
*   rename doc files
*   add quantitative comparisons of angular scattering
*   tweak verbiage
*   ignore more
*   initial commit
*   more cleanup
*   ignore dist files
*   minor reorg of contents
*   fix typos, add more refraction stuff
*   Changes to match PEP8 style
*   add minor comments, fix typos

1.0.0 (08/27/2017)
------------------
*   Added docs in form of Jupyter notebooks

0.4.2 (08/26/2017)
------------------
*   messed up github release 0.4.1

0.4.1 (08/26/2017)
------------------
*   fix typo

0.4.0 (08/26/2017)
------------------
*   update README to include basic testing
*   mie(m,x) work automatically with arrays
*   adding MANIFEST.in so examples get included

0.3.2 (07/07/2017)
------------------
*   update README, bump to 0.3.2
*   Fix examples so they work.

0.3.1 (07/07/2017)
------------------
*   Bump version.
*   Add functions to __init__.py.

0.3.0 (07/07/2017)
------------------
*   Update README again.
*   Update README.
*   More packaging issues.
*   Only include normalized scattering functions.
*   Tweak setup.py and add .gitignore.
*   Rename README.
*   Add small sphere calc for S1 and S2.
*   Label tests with MIEV0 cases.
*   Rename example.
*   Add gold sphere example.
*   Add a few example programs.
*   Remove unused tests.
*   Remove extraneous ; simplify test.py, add tests.
*   Simplify test suite management.
*   Rename awkward test_miepython to just test.
*   Reorganize tests, add S1 & S2 test.
*   Added capabilities. Barely working test suite.
*   Add more tests that fail.
*   Move files around.
*   Add boilerplate files and start adding unit tests.
*   Rename to miepython.
*   Initial check in.
